=======
Support
=======

.. toctree::
   :maxdepth: 1
   :hidden:

   feedback
   support_ticket

Want to give feedback, get help, chat and ask questions about Coiled and Dask,
or something else? Then you've come to the right place!

We love hearing from our users and community. Thank you for using Coiled, you
rock! 🤘

.. panels::
   :card: border-0
   :container: container-lg pb-3
   :column: col-md-4 col-md-4 col-md-4 p-2
   :body: text-center border-0
   :header: text-center border-0 h4 bg-white
   :footer: border-0 bg-white

   Have Feedback?
   ^^^^^^^^^^^^^^

   We'd love to hear your feature requests, suggestions, or other usability
   issues.

   +++

   .. link-button:: feedback
      :type: ref
      :text: Give us feedback
      :classes: btn-full btn-block stretched-link

   ---


   Need Help?
   ^^^^^^^^^^

   Report a bug or get help by opening a support ticket or emailing
   support@coiled.io.

   +++

   .. link-button:: support_ticket
      :type: ref
      :text: Open a support ticket
      :classes: btn-full btn-block stretched-link

   ---

   Want to Chat?
   ^^^^^^^^^^^^^

   Join Coiled users and engineers on our community Slack channel.

   +++

   .. link-button:: https://join.slack.com/t/coiled-users/shared_invite/zt-hx1fnr7k-In~Q8ui3XkQfvQon0yN5WQ
      :text: Join our community
      :classes: btn-full btn-block stretched-link


.. note::

    You can also browse the :doc:`faq` or :doc:`troubleshooting/index` for
    answers to your questions.

    Any security-related concerns can be reported to security@coiled.io.
